@@ -7,5 +7,6 @@ class TwitchTags(BaseModel):
     display_name: str
     color: Optional[str]
     user_id: str
-    mod: str
-    subscriber: str
+    broadcaster: bool = False
+    mod: bool
+    subscriber: bool
